@@ -2,5 +2,5 @@
 
 # empty module to bind functions
 
-from .connections import postIdToVideoSeq, getVpdid2, getVodId, getUpcoming
+from .connections import postIdToVideoSeq, getVpdid2, getVodId, getUpcomingList
 from .controllers import dumpSession, loadSession
